---
title: Understanding how to use the wall command in Linux
description: "The `wall` command in Linux is used to send broadcast messages to all logged-in users. It can be very useful for notifying users about upcoming server downtime, maintenance activities, or other urgent issues. With `wall`, administrators can quickly and efficiently…"
url: "https://truehost.com/support/knowledge-base/understanding-how-to-use-the-wall-command-in-linux/"
updated: "2024-11-06"
category: Cloud servers in Kenya
---

# Understanding how to use the wall command in Linux

The `wall` command in Linux is used to send broadcast messages to all logged-in users.

It can be very useful for notifying users about upcoming server downtime, maintenance activities, or other urgent issues.

With `wall`, administrators can quickly and efficiently alert users to any scheduled server events without need for additional software.

**Note:**

- You may need `sudo` permissions to use `wall` on some systems, especially when sending messages to all users. This means that you will use the user root or another sudo user.

## Common Options with wall Command

The Linux `wall` command has a few handy options you can use to tailor how it works. Here are some of the most popular ones:

- `-n`: Hides the banner that usually appears before the message.
- `-t timeout`: Sets a time limit for the message display. It will only stay visible for the number of seconds you specify.
- `-g group`: Sends the message only to users in a specific group.
- `-V`: Shows the version information, then exits.
- `-h`: Displays help details, then exits.

**Examples**

Below are some of the usecases

##### **Broadcast Simple Message**

- This is the most basic use. It send a broadcast message to all users that are logged in to the server's SSH

```
wall "We have scheduled a transfer from this server from 6 PM."
```

- The command above will display the message "**We have schedules a transfer from this server from 6 PM**" to all users that are logged in to the terminal.
- In the image below, the message is sent from user root's terminal and it pops up on a different user's terminal.

![](https://truehost.com/support/wp-content/uploads/2024/11/image-59-1024x521.png)

##### **Broadcast Message from File**[https://ultahost.com/knowledge-base/wall-command-linux/#h-broadcast-message-from-file](https://ultahost.com/knowledge-base/wall-command-linux/#h-broadcast-message-from-file)

- You can also send a broadcast message from a file. This becomes helpful it you aim to reuse the same message many times.
- You can ctaete your file and addd your text, then run the wall command with the following syntax
- Replace /path/to with the actual path to your file and myFile.txt with the actual name of your file.

```
wall /path/to/myFile.txx
```

![](https://truehost.com/support/wp-content/uploads/2024/11/image-60-1024x420.png)

##### **Using Timeout Option**

- The `-t` option lets you set how long the message will stay visible. The message will disappear after the specified time in seconds. For example:

```
wall -t 60 "We have scheduled a transfer from this server from 6 PM."
```

- This command will display “We have scheduled a transfer from this server from 6 PM.” for 60 seconds before it automatically disappears.

### Suppressing the Header

- By default, `wall` shows a header before your message. You can hide this header using the `-n` option:

```
wall -n "We have scheduled a transfer from this server from 6 PM."
```

- This command will display the message “We have scheduled a transfer from this server from 6 PM” without the header.

![](https://truehost.com/support/wp-content/uploads/2024/11/image-61-1024x437.png)

##### **Send Multi line Messages**[https://ultahost.com/knowledge-base/wall-command-linux/#h-send-multi-line-messages](https://ultahost.com/knowledge-base/wall-command-linux/#h-send-multi-line-messages)

- You can also send multi-lines message using the wall command.
- To do that, type the command ***wall*** then press **Enter**. You will then type your message and press **Enter** after each line.
- Once done with the typing, press ctrl+D to send the message

```
wall
Hello there
Please log out of your sessions
We want to reboot the server.
```

- The above command will display the multi-line message on the terminals of all logged in users.

##### **Broadcast Specific Groups**

##### The -g option with he wall command allows you to send messages to users in a specific group.

```
wall -g wheel "We are updating the root password."
```

- The above command will display the message “We are updating the root password.” only to users in the wheel group.

### Best Practices

- While the `wall` command is a powerful tool, it’s best to use it thoughtfully to avoid unnecessary disruptions. Here are some guidelines for using the `wall` command effectively:
  - Use `wall` only for important messages that all users need to see.
  - Keep messages clear and concise to avoid confusion.
  - Provide advance notice for any planned maintenance or shutdowns, so users have time to save their work and log out.
  - For complex messages, test them on a single terminal first to ensure they display properly.

### Author's Final Word

The `wall` command is a valuable tool for system administrators in multi-user environments. It enables quick and efficient broadcasting of messages to all logged-in users.

By following best practices and understanding the command’s options, you can communicate important updates effectively and keep users informed.

- In case you have any other queries relates to support,the **Truehost** Support team is always available to help pout. Please reach out to them **[here](https://wa.me/19726743814)**.
